import { Container } from "@/components/ui/container";
import { motion } from "framer-motion";
import { useReveal } from "@/hooks/use-reveal";

export default function BenefitsSection() {
  const { ref: titleRef, inView: titleInView } = useReveal();
  const { ref: quotesRef, inView: quotesInView } = useReveal({ delay: 0.2 });

  return (
    <section id="benefits" className="py-16 md:py-24 relative">
      <Container className="px-6 md:px-8">
        <div className="text-center mb-12 relative">
          {/* Elegant, subtle title */}
          <div className="flex items-center justify-center mb-4">
            <div className="h-[1px] w-6 bg-[#7B61FF]/30"></div>
            <span className="text-sm text-[#7B61FF] uppercase tracking-wider font-medium mx-3">THE RECURRO ADVANTAGE</span>
            <div className="h-[1px] w-6 bg-[#7B61FF]/30"></div>
          </div>
          
          <h2 className="text-3xl md:text-4xl font-medium text-gray-900 mb-6 leading-tight">
            What You Get With <span className="text-[#7B61FF] relative">
              Recurro
              <span className="absolute bottom-1 left-0 w-full h-[0.12em] bg-[#7B61FF]/20 rounded-full"></span>
            </span>
          </h2>
          
          {/* Decorative thin line with accent */}
          <div className="flex items-center justify-center mb-6">
            <div className="h-[1px] w-16 bg-gradient-to-r from-transparent to-[#7B61FF]/30"></div>
            <div className="h-1.5 w-1.5 rounded-full bg-[#7B61FF] mx-2"></div>
            <div className="h-[1px] w-16 bg-gradient-to-l from-transparent to-[#7B61FF]/30"></div>
          </div>
          
          <p className="text-gray-600 leading-relaxed mx-auto max-w-2xl">
            Recurro transforms your travel coordination from a time-consuming burden into a <span className="text-[#7B61FF] font-medium">strategic advantage</span>.
          </p>
        </div>
        
        {/* Main benefits - Mobile-first grid with fewer items and no scrolling */}
        <div className="md:hidden">
          <div className="grid grid-cols-2 gap-3 mb-4">
            <motion.div 
              ref={titleRef}
              initial={{ opacity: 0, y: 20 }}
              animate={titleInView ? { opacity: 1, y: 0 } : {}}
              transition={{ duration: 0.6 }}
              className="bg-white rounded-xl shadow-sm p-4 border border-gray-100"
            >
              <div className="w-10 h-10 bg-[#F7F0FF] rounded-lg flex items-center justify-center mb-3">
                <svg width="20" height="20" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
                  <path d="M12 8V12L15 15M21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3C16.9706 3 21 7.02944 21 12Z" stroke="#7B61FF" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round"/>
                </svg>
              </div>
              <h3 className="text-base font-medium text-gray-900 mb-1">Save 92% of Time</h3>
              <p className="text-gray-600 text-xs">
                Reduce booking time from hours to minutes.
              </p>
            </motion.div>
            
            <motion.div
              ref={quotesRef}
              initial={{ opacity: 0, y: 20 }}
              animate={quotesInView ? { opacity: 1, y: 0 } : {}}
              transition={{ duration: 0.6, delay: 0.1 }}
              className="bg-white rounded-xl shadow-sm p-4 border border-gray-100"
            >
              <div className="w-10 h-10 bg-[#F7F0FF] rounded-lg flex items-center justify-center mb-3">
                <svg width="20" height="20" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
                  <path d="M3 6L11 2L21 6M3 6L11 10M3 6V18L11 22M21 6L11 10M21 6V18L11 22M11 10V22" stroke="#7B61FF" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round"/>
                </svg>
              </div>
              <h3 className="text-base font-medium text-gray-900 mb-1">18% Cost Reduction</h3>
              <p className="text-gray-600 text-xs">
                Optimize travel spend with policy enforcement.
              </p>
            </motion.div>
          </div>
          
          <div className="grid grid-cols-2 gap-3">
            <motion.div
              initial={{ opacity: 0, y: 20 }}
              animate={quotesInView ? { opacity: 1, y: 0 } : {}}
              transition={{ duration: 0.6, delay: 0.2 }}
              className="bg-white rounded-xl shadow-sm p-4 border border-gray-100"
            >
              <div className="w-10 h-10 bg-[#F7F0FF] rounded-lg flex items-center justify-center mb-3">
                <svg width="20" height="20" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
                  <path d="M13 10V3L4 14H11V21L20 10H13Z" stroke="#7B61FF" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round"/>
                </svg>
              </div>
              <h3 className="text-base font-medium text-gray-900 mb-1">Instant Response</h3>
              <p className="text-gray-600 text-xs">
                Get alerts and intelligent rebooking options.
              </p>
            </motion.div>
            
            <motion.div
              initial={{ opacity: 0, y: 20 }}
              animate={quotesInView ? { opacity: 1, y: 0 } : {}}
              transition={{ duration: 0.6, delay: 0.3 }}
              className="bg-white rounded-xl shadow-sm p-4 border border-gray-100"
            >
              <div className="w-10 h-10 bg-[#F7F0FF] rounded-lg flex items-center justify-center mb-3">
                <svg width="20" height="20" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
                  <path d="M9 12L11 14L15 10M21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3C16.9706 3 21 7.02944 21 12Z" stroke="#7B61FF" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round"/>
                </svg>
              </div>
              <h3 className="text-base font-medium text-gray-900 mb-1">Maximum Rewards</h3>
              <p className="text-gray-600 text-xs">
                Optimize loyalty programs across teams.
              </p>
            </motion.div>
          </div>
        </div>
        
        {/* Desktop/tablet view - traditional grid layout */}
        <div className="hidden md:grid md:grid-cols-3 gap-8">
          <motion.div 
            ref={titleRef}
            initial={{ opacity: 0, y: 30 }}
            animate={titleInView ? { opacity: 1, y: 0 } : {}}
            transition={{ duration: 0.8 }}
            className="bg-white rounded-xl shadow-sm p-8 border border-gray-100"
          >
            <div className="w-16 h-16 bg-[#F7F0FF] rounded-lg flex items-center justify-center mb-6">
              <svg width="32" height="32" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
                <path d="M12 8V12L15 15M21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3C16.9706 3 21 7.02944 21 12Z" stroke="#7B61FF" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round"/>
              </svg>
            </div>
            <h3 className="text-xl font-medium text-gray-900 mb-3">Save 92% of Time</h3>
            <p className="text-gray-600">
              Reduce travel booking time from hours to minutes with automated coordination and intelligent trip generation.
            </p>
          </motion.div>
          
          <motion.div
            ref={quotesRef}
            initial={{ opacity: 0, y: 30 }}
            animate={quotesInView ? { opacity: 1, y: 0 } : {}}
            transition={{ duration: 0.8, delay: 0.1 }}
            className="bg-white rounded-xl shadow-sm p-8 border border-gray-100"
          >
            <div className="w-16 h-16 bg-[#F7F0FF] rounded-lg flex items-center justify-center mb-6">
              <svg width="32" height="32" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
                <path d="M3 6L11 2L21 6M3 6L11 10M3 6V18L11 22M21 6L11 10M21 6V18L11 22M11 10V22" stroke="#7B61FF" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round"/>
              </svg>
            </div>
            <h3 className="text-xl font-medium text-gray-900 mb-3">18% Cost Reduction</h3>
            <p className="text-gray-600">
              Optimize travel spend with policy enforcement, loyalty program integration, and transparent pricing.
            </p>
          </motion.div>
          
          <motion.div
            initial={{ opacity: 0, y: 30 }}
            animate={quotesInView ? { opacity: 1, y: 0 } : {}}
            transition={{ duration: 0.8, delay: 0.2 }}
            className="bg-white rounded-xl shadow-sm p-8 border border-gray-100"
          >
            <div className="w-16 h-16 bg-[#F7F0FF] rounded-lg flex items-center justify-center mb-6">
              <svg width="32" height="32" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
                <path d="M13 10V3L4 14H11V21L20 10H13Z" stroke="#7B61FF" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round"/>
              </svg>
            </div>
            <h3 className="text-xl font-medium text-gray-900 mb-3">Instant Response</h3>
            <p className="text-gray-600">
              Get proactive assistance with flight changes, real-time alerts, and intelligent rebooking options.
            </p>
          </motion.div>
        </div>
        
        <div className="hidden md:grid md:grid-cols-2 gap-8 mt-8">
          <div className="bg-white rounded-xl shadow-md p-8 border border-gray-100">
            <div className="flex items-center mb-6">
              <div className="w-12 h-12 bg-[#7B61FF] rounded-full flex items-center justify-center text-white mr-4">
                <svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
                  <path d="M13.5 4.5L21 12L13.5 19.5M10.5 19.5L3 12L10.5 4.5" stroke="white" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round"/>
                </svg>
              </div>
              <h3 className="text-xl font-medium text-gray-900">Streamlined Workflows</h3>
            </div>
            <p className="text-gray-600 leading-relaxed">
              Simplify your travel program with automated approvals, policy compliance, and seamless integration with your existing systems.
            </p>
          </div>
          
          <div className="bg-white rounded-xl shadow-md p-8 border border-gray-100">
            <div className="flex items-center mb-6">
              <div className="w-12 h-12 bg-[#7B61FF] rounded-full flex items-center justify-center text-white mr-4">
                <svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
                  <path d="M9 12L11 14L15 10M21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3C16.9706 3 21 7.02944 21 12Z" stroke="white" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round"/>
                </svg>
              </div>
              <h3 className="text-xl font-medium text-gray-900">Maximum Rewards</h3>
            </div>
            <p className="text-gray-600 leading-relaxed">
              Optimize loyalty programs across your organization to maximize points, status, and upgrades while maintaining complete visibility.
            </p>
          </div>
        </div>
      </Container>
    </section>
  );
}